require_relative "../../../../base"

describe "VagrantPlugins::GuestSUSE::Cap::ChangeHostName" do
  let(:caps) do
    VagrantPlugins::GuestSUSE::Plugin
      .components
      .guest_capabilities[:suse]
  end

  let(:machine) { double("machine") }
  let(:comm) { VagrantTests::DummyCommunicator::Communicator.new(machine) }

  before do
    allow(machine).to receive(:communicate).and_return(comm)
  end

  after do
    comm.verify_expectations!
  end

  describe ".change_host_name" do
    let(:cap) { caps.get(:change_host_name) }

    let(:name) { "banana-rama.example.com" }
    let(:basename) { "banana-rama" }

    it "sets the hostname" do
      comm.stub_command('test "$(hostnamectl --static status)" = "#{basename}"', exit_code: 1)

      cap.change_host_name(machine, name)
      expect(comm.received_commands[1]).to match(/hostnamectl set-hostname '#{basename}'/)
    end

    it "does not change the hostname if already set" do
      comm.stub_command('test "$(hostnamectl --static status)" = "#{basename}"', exit_code: 0)

      cap.change_host_name(machine, name)
      expect(comm.received_commands.size).to eq(1)
    end
  end
end
